@@ -43,9 +43,6 @@ Django's management scripts you gain several advantages:
     * You get auto-reloading for *all* processes when running in debug mode.
     * Process configuration can depend on Django settings and environment
       variables, and have paths relative to your project and/or apps.
-    * Apps can provide default process configurations, which projects can
-      then tweak or override as needed.
-
 
 
 Configuration
@@ -93,19 +90,6 @@ server when debugging but run under FCGI in production::
     {% endif %}
  
 
-For more flexibility, django-supervisor also supports per-application config
-files.  For each application in INSTALLED_APPS, it will search for config
-files in the following locations:
-
-   * <app directory>/management/supervisord.conf
-   * djsupervisor/contrib/<app name>/supervisord.conf
-
-Any files so found will be merged together, and then merged with your project
-configuration to produce the final supervisord config.  This allows you to
-include basic process management definitions as part of a reusable Django
-application, and tweak or override them on a per-project basis.
-
-
 Usage
 -----
 
@@ -220,6 +204,16 @@ configuration file contains the following variables::
 
     environ              the os.environ dict, as seen by your code.
 
+If your project has other configuration files that need to interpolate these
+values, you can refer to them via the "templated" filter, like this::
+
+    [program:nginx]
+    command=nginx -c {{ "nginx.conf"|templated }}
+
+The file path is relative to your project directory.  Django-supervisor will
+read the specified file, pass it through its templating logic, write out a
+matching "nginx.conf.templated" file, and insert the path to this file as the
+result of the filter.
 
 
 Defaults, Overrides and Excludes
@@ -252,9 +246,8 @@ Here's an example config file that shows them all in action::
     [program:__overrides__]
     user=nobody
 
-    ; Django-supervisord ships with a default configuration for celerybeat.
-    ; We don't use it, so remove it from the config.
-    [program:celerybeat]
+    ; Don't reload programs when python code changes.
+    [program:autoreload]
     exclude=true
 
 
@@ -298,20 +291,11 @@ option to supervisor or just exclude it in your project config file like so::
     [program:autoreload]
     exclude=true
 
-
-
-More Info
----------
-
-There aren't any more docs online yet.  Sorry.  I'm working on a little tutorial
-and some examples, but I need to actually *use* the project a little more
-first to make sure it all fits together the way I want...
-
 """
 
 __ver_major__ = 0
-__ver_minor__ = 2
-__ver_patch__ = 7
+__ver_minor__ = 3
+__ver_patch__ = 0
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
