@@ -1,3 +1,6 @@
+
+import time
+
 from watchdog.events import PatternMatchingEventHandler
 
 
@@ -8,9 +11,14 @@ class CallbackModifiedHandler(PatternMatchingEventHandler):
     """
     def __init__(self, callback, *args, **kwargs):
         self.callback = callback
+        self.repeat_delay = kwargs.pop("repeat_delay", 0)
+        self.last_fired_time = 0
         super(CallbackModifiedHandler, self).__init__(*args, **kwargs)
 
     def on_modified(self, event):
         super(CallbackModifiedHandler, self).on_modified(event)
-        if not event.is_directory:
-            self.callback()
+        now = time.time()
+        if self.last_fired_time + self.repeat_delay < now:
+            if not event.is_directory:
+                self.last_fired_time = now
+                self.callback()
